@@ -17,6 +17,9 @@ class AllColumns(SqlExpr):
     def __hash__(self):
         return hash(str(self))
 
+    def symbol_name(self):
+        return 'star'
+
     def all_symbols(self, relations):
         sym = [r.all_symbols(self) for r in relations if r.alias_match(str(self))]
         if len(sym) == 0:
@@ -25,7 +28,8 @@ class AllColumns(SqlExpr):
 
     @property
     def is_key_count(self):
-        # should be true if no table specified and row_privacy
+        # can only be key_count if metadata specifies row_privacy,
+        # which is set by load_symbols
         return False
 
     @property
